@@ -1,10 +1,10 @@
 /* filename: rlpr-dbfile.c
  * project: rlpr
  * author: meem  --  meem@sherilyn.wustl.edu
- * version: $Id: rlpr-dbfile.c,v 1.8 1996/11/19 01:15:48 meem Exp $
+ * version: $Id: rlpr-dbfile.c,v 1.8 1996/11/19 01:15:48 meem Exp meem $
  * contents: procedures for the rlpr database file
  * 
- * Time-stamp: <1996/11/16 19:44 -- meem@sherilyn.wustl.edu>
+ * Time-stamp: <1997/02/25 17:40 -- meem@sherilyn.wustl.edu>
  */
 
 /* copyright (c) 1996 meem, meem@gnu.ai.mit.edu
@@ -25,14 +25,15 @@
 #include <stdio.h>		      /* for FILE*, etc */
 #include <string.h>
 #include <stdlib.h>		      /* for getenv() */
-#include "rlpr-common.h"
+#include "rlpr-msg.h"
+#include "rlpr-util.h"
 #include "rlpr-dbfile.h"
 #include "rlpr-client.h"	      /* common to parts of the rlpr client */
 
 static char *dbfilename = NULL;
 static FILE *dbp;
 
-void opendbfile(void) {
+int opendbfile(void) {
   char *home;
 
   if (!(home = getenv("HOME")))
@@ -41,10 +42,15 @@ void opendbfile(void) {
   dbfilename = rlpr_malloc(strlen(home) + strlen(DBNAME) + 2);
   sprintf(dbfilename, "%s/%s", home, DBNAME);
 
-  if ((dbp = fopen(dbfilename, "r")) == NULL)
-    /* no local one, lets look for a systemwide one */
-    if ((dbp = fopen(DEFAULT_SYS_DBNAME, "r")) == NULL)
-      rlpr_msg(FATAL, ERRNO, "%s - cannot open", DEFAULT_SYS_DBNAME);
+  if ((dbp = fopen(dbfilename, "r")) == NULL) {
+    rlpr_msg(DEBUG, NO_ERRNO, "no %s -- checking for systemwide", dbfilename);
+    if ((dbp = fopen(DEFAULT_SYS_DBNAME, "r")) == NULL) {
+      rlpr_msg(DEBUG, NO_ERRNO, "no systemwide %s found either, giving up",
+	       DEFAULT_SYS_DBNAME);
+      return -1;
+    }
+  }
+  return 0;
 }
 
 void closedbfile(void) {
@@ -56,7 +62,7 @@ void closedbfile(void) {
 
 char * getqfromhost(char *printhost) {
   char *queue;			      /* what this returns */
-  opendbfile();
+  if (opendbfile() == -1) return NULL;
 
   if ((queue = db_search(printhost, FINDQ)) == NULL)
     rlpr_msg(FATAL, NO_ERRNO, 
@@ -67,7 +73,7 @@ char * getqfromhost(char *printhost) {
 
 char * gethostfromq(char *queue) {
   char *printhost;		      /* returned by db_search */
-  opendbfile();  
+  if (opendbfile() == -1) return NULL;
 
   if ((printhost = db_search(queue, FINDHOST)) == NULL)
     rlpr_msg(FATAL, NO_ERRNO,
