@@ -1,10 +1,10 @@
 /* filename: rlpr-dbfile.h
  * project: rlpr
  * author: meem  --  meem@sherilyn.wustl.edu
- * version: $Id: rlpr-dbfile.h,v 1.4 1996/10/12 07:09:02 meem Exp $
+ * version: $Id: rlpr-dbfile.h,v 1.4 1996/10/12 07:09:02 meem Exp meem $
  * contents: prototypes and #defines for rlpr database file manipulation
  *
- * Time-stamp: <1996/10/12 02:08 -- meem@sherilyn.wustl.edu>
+ * Time-stamp: <1997/02/25 17:39 -- meem@sherilyn.wustl.edu>
  */
 
 #ifndef RLPR_DBFILE_H
@@ -21,7 +21,7 @@
 /* function prototypes */
 char * getqfromhost(char *printhost);     /* finds a printqueue name from a host */
 char * gethostfromq(char *queue);         /* finds a host from a printqueue name */
-void   opendbfile(void);                  /* opens the DBNAME file */
+int    opendbfile(void);                  /* opens the DBNAME file */
 void   closedbfile(void);                 /* closes the DBNAME file */
 char * db_search(char *sstr, int TYPE);   /* main search engine */
 
