@@ -1,11 +1,11 @@
 /* filename: rlprd.c
  * project: rlpr
  * author: meem  --  meem@sherilyn.wustl.edu
- * version: $Id: rlprd.c,v 1.13 1997/01/16 16:44:11 meem Exp $
+ * version: $Id: rlprd.c,v 1.13 1997/01/16 16:44:11 meem Exp meem $
  * contents: daemon which does "reflecting" of messages from non-privileged
  *           to privileged ports
  *
- * Time-stamp: <1997/01/16 10:40 -- meem@sherilyn.wustl.edu>
+ * Time-stamp: <1997/04/27 01:21:33 cdt -- meem@sherilyn.wustl.edu>
  */
 
 /* copyright (c) 1996, 1997 meem, meem@gnu.ai.mit.edu
@@ -23,42 +23,45 @@
 
 #include "config.h"
 
-#include <sys/types.h>          /* for pid_t */
-#include <signal.h>
-
 #ifndef STDC_HEADERS
 #error there is currently no support for compiling on machines without ANSI headers. \
        write meem@gnu.ai.mit.edu if you are interested in adding it.
 #endif
 
-#ifdef __GNU_LIBRARY__                    
-#undef __GNU_LIBRARY__
-#include "getopt.h"
-#define __GNU_LIBRARY__
-#else  /* not __GNU_LIBRARY__ */
-#include "getopt.h"
-#endif /* not __GNU_LIBRARY__ */
+#include <sys/types.h>
+#include <signal.h>
+#include <unistd.h>		       /* for geteuid(), ...       */
+#include <stdlib.h>		       /* for EXIT_* constants, .. */
+#include <sys/time.h>		       /* for select()             */
+#include <netdb.h>		       /* for gethostbyaddr()      */
+#include <sys/stat.h>		       /* for umask()              */
 
+#ifdef SYSLOG_USABLE
+#include <syslog.h>
+#endif /* SYSLOG_USABLE */
+
+#include <stdio.h>
+
+#include "getopt.h"
 #include "wait.h"
-
-#include <syslog.h>                   /* for openlog() (for now) */
-#include <stdlib.h>                   /* for EXIT_* constants */
-#include <netdb.h>                    /* for gethostbyname() */
-#include <sys/time.h>                 /* select() and macros */
-#include <sys/stat.h>                 /* for umask() */
-#include <unistd.h>                   /* for setsid() */
-#include <string.h>                   /* for strerror() */
-#include <errno.h>
-#include <stdio.h>                    /* BUFSIZ */
-#include <netinet/in.h>               /* for sockaddr_in */
-#include <stdarg.h>
-
+#include "rlpr-rfc1179.h"
 #include "rlprd.h"
-#include "rlpr-common.h"
+#include "rlpr-msg.h"
+#include "rlpr-util.h"
+       
+static void         register_sigchld(void);
+static void         register_sigalrm(void);
+static RETSIGTYPE   sigchld(int unused);
+static RETSIGTYPE   sigalrm(int unused);
+static const char * hostname(struct sockaddr_in *sin);
+static ssize_t      readstr(int fd, char * buf, size_t bufsz);
+static void         converse(int client, int server);
 
-static daemon_options d_opts_;
+static rlpr_rlprd_info rlpr_rlprd_props;
+extern struct option   rlpr_long_opts[]; 
+extern const char *    rlpr_opts;
 
-char * name;                          /* program name */
+char * program_name;		      /* program name */
 
 int main(int argc, char *argv[]) {
   struct sockaddr_in sin_in;          /* where we will listen */
@@ -70,20 +73,20 @@ int main(int argc, char *argv[]) {
   int    sin_fromlen = sizeof sin_from; /* the length of the incoming desc */
   char   printhost[MAXHOSTNAMELEN + 1]; /* name of printhost */
   char   localhost[MAXHOSTNAMELEN + 1]; /* for finding out our name */
-  pid_t  childpid;                    /* for fork() */
   int    orig_argc = argc;            /* original # args */
 
-  name = *argv;
+  program_name = argv[0];
 
-  argc -= parse_args(orig_argc, argv);
+  argc -= rlpr_rlprd_args(orig_argc, argv);
   argv += orig_argc - argc;
 
   if (geteuid() != 0)
     rlpr_msg(FATAL, NO_ERRNO, "must be run root or setuid root!");
 
-  toggle_euid();                          /* lose root */
+  toggle_euid();		       /* lose root */
 
-  if (d_opts_.daemon) daemon_init();      /* if daemon, do the magic */
+  if (rlpr_rlprd_props.daemon) 
+    daemon_init();		       /* if daemon, do the magic */
 
   if (get_local_hostname(localhost, sizeof(localhost)) == -1)
     rlpr_msg(FATAL, NO_ERRNO, "unable to resolve your local hostname!");
@@ -93,19 +96,19 @@ int main(int argc, char *argv[]) {
   
   /* initialize and fill in what we can up front */
   
-  init_sockaddr(&sin_in,   NULL,      d_opts_.port); 
+  init_sockaddr(&sin_in,   NULL,      rlpr_rlprd_props.port); 
   init_sockaddr(&sin_out,  localhost, 0); 
   init_sockaddr(&sin_from, NULL,      0);
 
   sin_in.sin_addr.s_addr = htonl(INADDR_ANY);
 
   if (bind(listen_fd,  (struct sockaddr *) &sin_in,  sizeof(sin_in)) < 0)
-    rlpr_msg(FATAL, ERRNO, "bind to port %hi failed", d_opts_.port);
+    rlpr_msg(FATAL, ERRNO, "bind to port %hi failed", rlpr_rlprd_props.port);
   
   register_sigchld();               /* register the reaper */
   register_sigalrm();               /* register the alarm */
 
-  rlpr_msg(DEBUG, NO_ERRNO, "listening on port %hi...", d_opts_.port);
+  rlpr_msg(DEBUG, NO_ERRNO, "listening on port %hi...", rlpr_rlprd_props.port);
   listen(listen_fd, 5);             /* don't rely on more than 5 */
 
   for (;;) {
@@ -130,7 +133,7 @@ int main(int argc, char *argv[]) {
 
     /* CHILD */
 
-    alarm(d_opts_.timeout);   /* set timeout */
+    alarm(rlpr_rlprd_props.timeout);   /* set timeout */
     
     if (readstr(inc_rlprd, printhost, MAXHOSTNAMELEN) < 0)
       rlpr_msg(FATAL, NO_ERRNO, "unable to read proxy hostname");     
@@ -140,20 +143,20 @@ int main(int argc, char *argv[]) {
 
     /* bind our local socket so we come from a privileged port */
 
+    toggle_euid();                            /* gain root */
+
     if ((out_lpd = socket(AF_INET, SOCK_STREAM, 0)) < 0)
       rlpr_msg(FATAL, ERRNO, "socket");
 
-    toggle_euid();                            /* gain root */
-
-    if (bind_try_range(&sin_out, LO_LPD_FROM_PORT, HI_LPD_FROM_PORT, out_lpd) < 0)
+    if (bind_try_range(&sin_out, LO_LPD_DST_PORT, HI_LPD_DST_PORT, out_lpd) < 0)
       rlpr_msg(FATAL, ERRNO,
-               "bind to ports %hi-%hi", LO_LPD_FROM_PORT, HI_LPD_FROM_PORT);
+               "bind to ports %hi-%hi", LO_LPD_DST_PORT, HI_LPD_DST_PORT);
 
     toggle_euid();                            /* lose root */
       
     /* initialize sin_lpd and connect to the host running lpd */
 
-    init_sockaddr(&sin_lpd, printhost, LPD_TO_PORT);
+    init_sockaddr(&sin_lpd, printhost, LPD_DST_PORT);
 
     if (connect(out_lpd, (struct sockaddr *) &sin_lpd, sizeof(sin_lpd)) < 0)
       rlpr_msg(FATAL, ERRNO, "connect");
@@ -209,16 +212,18 @@ void converse(int client, int server) {
  *  output: void
  */ 
 
-static void daemon_init(void) {
+void daemon_init(void) {
+  int syslog_on = 1;
 
   if (getppid() > 1) {  
     /* we weren't started by init.  let's fork ourselves silly */
     
     /* turn on the logger */
-#ifdef HAVE_SYSLOG_H
-    openlog(name, LOG_PID, LOG_LPR);
-#endif /* HAVE_SYSLOG_H */
-    props_.syslog = 1;
+#ifdef SYSLOG_USABLE
+    openlog(program_name, LOG_PID, LOG_LPR);
+#endif /* SYSLOG_USABLE */
+    
+    rlpr_msg_set(RLPR_MSG_SYSLOG, &syslog_on);
 
     switch (fork()) {
       case  0: break;
@@ -252,7 +257,6 @@ static const char * hostname(struct sockaddr_in *sin) {
   return hp->h_name;
 }
      
-
 static RETSIGTYPE sigchld(int unused) {
   int olderrno = errno;
   while (waitpid( -1, NULL, WNOHANG) > 0) /* NULL BODY */;
@@ -263,13 +267,6 @@ static RETSIGTYPE sigalrm(int unused) {
   rlpr_msg(FATAL, NO_ERRNO, "connection timed out");
 }
 
-/* register_sigchld()
- *
- * purpose: to register the SIGCHLD signal with the reaper
- *   input: void
- *  output: void
- */ 
-
 static void register_sigchld(void) {
   struct sigaction sa;
   sa.sa_handler = sigchld;
@@ -290,8 +287,8 @@ static void register_sigalrm(void) {
 
 /* read at most bufsz characters into buf, stopping at the first \n */
 
-static int readstr(int fd, char * buf, int bufsz) {
-  int i;
+static ssize_t readstr(int fd, char * buf, size_t bufsz) {
+  size_t i;
   
   for (i = 0; i < bufsz; i++) {
     if (read(fd, &buf[i], 1) < 0) return -1;
@@ -301,77 +298,52 @@ static int readstr(int fd, char * buf, int bufsz) {
   return i;
 }
 
-/* parse_args()
- *
- * purpose: to handle command line arguments
- *   input: argc  the number of elements in argv
- *          argv  an array of command line arguments
- *  output: void
- */ 
+static void rlpr_rlprd_init(void) {
+  rlpr_rlprd_props.port    = RLPRD_DST_PORT;
+  rlpr_rlprd_props.timeout = RLPRD_TIMEOUT;
+  rlpr_rlprd_props.daemon  = 1;          /* daemon on */
+}
 
-static int parse_args(int argc, char *argv[]) {
-  int c;
-  int num_args = 1;
+int rlpr_rlprd_args(int argc, char *argv[]) {
+  int c, num_args = 1;
+  extern int optind;
 
-  static struct option long_opts[] = {
-    { "debug",        0, NULL, 'd' },
-    { "no-daemon",    0, NULL, 'n' },
-    { "port",         1, NULL, 'p' },
-    { "quiet",        0, NULL, 'q' },
-    { "silent",       0, NULL, 'q' },
-    { "timeout",      1, NULL, 't' },
-    { "version",      0, NULL, 'V' },
-    { 0, 0, 0, 0 }
-  };
+  rlpr_rlprd_init();
+  rlpr_msg_args(argc, argv);	/* initialize the messaging subsystem */
 
-  init_options();
-  
-
-  while ((c = getopt_long(argc, argv, "np:qtvV", long_opts, NULL)) != EOF) {
+  optind = 0;
+  while ((c = getopt_long(argc, argv, rlpr_opts, rlpr_long_opts, NULL)) != EOF) {
     num_args++;
     switch(c) {
-    case 'd':
-      props_.debug    = 1;
-      break;
     case 'n':
-      d_opts_.daemon  = 0;
+      rlpr_rlprd_props.daemon  = 0;
       break;
     case 'p':
-      d_opts_.port    = atoi(optarg);
-      break;
-    case 'q':
-      props_.quiet    = 1;
+      rlpr_rlprd_props.port    = atoi(optarg);
       break;
     case 't':
-      d_opts_.timeout = atoi(optarg);
+      rlpr_rlprd_props.timeout = atoi(optarg);
       break;
     case 'V':
       fprintf(stdout, "%s: version "VERSION" from "__DATE__" "__TIME__ 
-              " -- meem@gnu.ai.mit.edu\n", name);
+              " -- meem@gnu.ai.mit.edu\n", program_name);
       exit(EXIT_SUCCESS);
-    case '?':
-      fprintf(stderr,"please see manpage for help\n");
-      break;
-    default:
-      break; /* just in case */
     }
   }
+
   return num_args;
 }
 
+struct option rlpr_long_opts[] = {
+  { "no-daemon", 0, NULL, 'n' },
+  { "port"    ,  1, NULL, 'p' },
+  { "timeout" ,  1, NULL, 't' },
+  { "version" ,  0, NULL, 'V' },
+  { "debug"   ,  0, NULL, -101 },
+  { "quiet"   ,  0, NULL, 'q'  },
+  { "silent"  ,  0, NULL, 'q'  },
+  { "verbose" ,  0, NULL, -102 },
+  { 0, 0, 0, 0 }
+};
 
-/* init_options()
- *
- * purpose: to provide reasonable defaults for the d_opts_ struct
- *   input: void (uses evil global variables)
- *  output: void
- */ 
-
-void init_options(void) {
-  props_.debug    = 0;
-  props_.quiet    = 0;
-  props_.syslog   = 0;
-  d_opts_.port    = DEFAULT_RLPRD_TO_PORT;
-  d_opts_.timeout = DEFAULT_TIMEOUT;
-  d_opts_.daemon  = 1;          /* daemon on */
-}
+const char * rlpr_opts = "np:tVq";
